@@ -630,6 +630,38 @@ class DatabaseManager:
         '''
         _cfu.writer.to_json(self.master_summary_path,self.master_summary)
 
+    def get_table(self,name:str,schema:_Union[None,str]=None)->_Union[_table_manager.TableManager,None]:
+        '''
+            Get a table from this database.
+
+            ----------
+
+            Arguments
+            -------------------------
+            `name` {str|list}
+                The name or list of names of tables to retrieve the instances of.
+
+            [`schema`=None] {str}
+                The schema to search within, if not provided, it will return the first match.
+
+            Return {TableManager|None}
+            ----------------------
+            The tableManager instance or None if it cannot be found.
+
+            Meta
+            ----------
+            `author`: Colemen Atwood
+            `created`: 06-01-2022 14:05:18
+            `memberOf`: DatabaseManager
+            `version`: 1.0
+            `method_name`: get_table
+            * @xxx [06-07-2022 11:00:38]: documentation for get_table
+        '''
+        result = self.table(name,schema)
+        if result is not None and isinstance(result,(list)) is False:
+            return result
+        return None
+
     def table(self,name:_Union[list,str],schema:_Union[None,str]=None)->_Union[_Iterable[_table_manager.TableManager],_table_manager.TableManager,None]:
         '''
             Get a table from this database.
