@@ -296,6 +296,7 @@ class TableDataManager:
 
         path = self.insert_path
         if _cfu.exists(path):
+            # print(f"deleting insert file: {path}")
             return _cfu.delete(path)
         return True
 
@@ -383,7 +384,7 @@ class TableDataManager:
         # @Mstep [IF] if data is None
         if data is None:
             # @Mstep [] set the insert data to an empty list.
-            self.db.insert_data[self.name] = []
+            self.db.insert_data[self.insert_type][self.name] = []
             self.save(True)
             # @Mstep [RETURN] return True
             return True
