@@ -19,12 +19,10 @@ from colorama import Fore as _Fore
 from colorama import Style as _Style
 import utils.list_utils as _lu
 
-
-
-
-def set_defaults(default_vals, obj):
+def set_defaults(default_vals, obj,**kwargs):
     '''
-        Sets default values on the dict provided, if they do not already exist.
+        Sets default values on the dict provided, if they do not already exist or 
+        if the value is None.
 
         ----------
 
@@ -37,8 +35,8 @@ def set_defaults(default_vals, obj):
 
         Keyword Arguments
         -------------------------
-        `arg_name` {type}
-                arg_description
+        [`replace_null`=False] {bool}
+            If True, None values in the obj dict are overwritten by the defaults.
 
         Return {dict}
         ----------------------
@@ -52,12 +50,47 @@ def set_defaults(default_vals, obj):
         `version`: 1.0
         `method_name`: set_defaults
     '''
+    replace_null = get_kwarg(['replace null'],False,(bool),**kwargs)
+    
     for k, v in default_vals.items():
+        if replace_null:
+            if k in obj:
+                if obj[k] is None:
+                    obj[k] = v
+
         if k not in obj:
             obj[k] = v
         # print(f"k: {k} - v: {v}")
     return obj
 
+def merge(dict_one:dict,dict_two:dict)->dict:
+    '''
+        Merge two dictionaries into one.
+
+        ----------
+
+        Arguments
+        -------------------------
+        `dict_one` {dict}
+            The first dict to merge.
+        `dict_two` {dict}
+            The second dict to merge.
+
+        Return {dict}
+        ----------------------
+        The merged dictionary
+
+        Meta
+        ----------
+        `author`: Colemen Atwood
+        `created`: 06-05-2022 14:19:19
+        `memberOf`: dict_utils
+        `version`: 1.0
+        `method_name`: merge
+        * @xxx [06-05-2022 14:20:44]: documentation for merge
+    '''
+    return {**dict_one,**dict_two}
+
 def keys_to_lower(dictionary):
     '''
         Converts all keys in a dictionary to lowercase.
@@ -94,8 +127,6 @@ def keys_to_list(data:dict)->list:
 
     return list(data.keys())
 
-
-
 def get_kwarg(key_name:_Union[list,str], default_val=False, value_type=None, **kwargs):
     '''
         Get a kwarg argument that optionally matches a type check or
